# eric7.Plugins.VcsPlugins.vcsGit.GitTagDialog

Module implementing a dialog to enter the data for a tagging operation.

### Global Attributes

None

### Classes

GitTagDialog | Class implementing a dialog to enter the data for a tagging operation.
GitTagOperation | Class defining the supported git tag operations.
GitTagType | Class defining the supported git tag types.

### Functions

None

## GitTagDialog

Class implementing a dialog to enter the data for a tagging operation.

### Derived from

QDialog, Ui_GitTagDialog

### Class Attributes

None

### Class Methods

None

### Methods

GitTagDialog | Constructor
getParameters | Public method to retrieve the tag data.
on_tagCombo_editTextChanged | Private method used to enable/disable the OK-button.

### Static Methods

None

#### GitTagDialog (Constructor)

GitTagDialog(taglist, revision=None, tagName=None, parent=None)

Constructor

taglist (list of str)
  list of previously entered tags
revision (str)
  revision to set tag for
tagName (str)
  name of the tag
parent (QWidget)
  parent widget

#### GitTagDialog.getParameters

getParameters()

Public method to retrieve the tag data.

Return:
  tuple containing the tag, revision, tag operation, tag type, and a flag indicating to enforce the operation

Return Type:
  tuple of (str, str, GitTagOperation, GitTagType, bool)

#### GitTagDialog.on_tagCombo_editTextChanged

on_tagCombo_editTextChanged(text)

Private method used to enable/disable the OK-button.

text (str)
  tag name entered in the combo

Up

## GitTagOperation

Class defining the supported git tag operations.

### Derived from

enum.Enum

### Class Attributes

Create
Delete
Verify

### Class Methods

None

### Methods

None

### Static Methods

None

Up

## GitTagType

Class defining the supported git tag types.

### Derived from

enum.Enum

### Class Attributes

Annotated
Local
Signed

### Class Methods

None

### Methods

None

### Static Methods

None

Up